<?php

namespace App\Http\Controllers;

use App\Models\Categories;
use App\Models\ContactMessage;
use App\Models\Orders;
use App\Models\ProductImages;
use App\Models\Products;
use App\Models\Setting;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Validator;
use Auth;
use Illuminate\Support\Str;
use Session;



class ManageWebsiteFunctionality extends Controller
{

    public function categories()
    {
        $categories = Categories::orderBy('id', 'desc')->get();
        return view("admin.categories", compact('categories'));
    }

    public function savecategories(Request $request)
    {
        if ($request->hasFile('image')) {
            $validator = Validator::make($request->all(), [
                'image' => 'required|image|mimes:jpg,png,jpeg,gif,svg,webp',
                'name' => 'required'
            ]);
        }

        if ($validator->fails()) {
            return back()->with('error', 'Name & Image Is Required');
        }
        $data['name'] = $request->name;

        if ($request->hasFile('image')) {
            $image = $request->file('image');
            $image_new = time() . $image->getClientOriginalName();
            $image->move('admin/assets/uploads/', $image_new);
            $data['image'] = $image_new;
        }

        Categories::create($data);
        return back()->with('success', 'Data Successfully Added !');
    }

    public function updatecategory(Request $request)
    {
        $getData = Categories::findOrFail(decrypt($request->id));

        if (isset($request->name)) {
            $getData->name = $request->name;
        }
        if ($request->hasFile('image')) {
            $validator = Validator::make($request->all(), [
                'image' => 'required|image|mimes:jpg,png,jpeg,gif,svg,webp'
            ]);

            if ($validator->fails()) {
                return back()->with('error', 'Invalid image');
            }

            if (\File::exists(public_path('admin/assets/uploads/' . $getData->image))) {

                \File::delete(public_path('admin/assets/uploads/' . $getData->image));
            }

            $image = $request->file('image');
            $image_new = time() . $image->getClientOriginalName();
            $image->move('admin/assets/uploads/', $image_new);
            $getData->image = $image_new;
        }
        $getData->save();
        return back()->with('success', 'Successfully Updated !');
    }

    public function deletecategory($id)
    {
        $getData = Categories::findOrFail(decrypt($id));
        if (\File::exists(public_path('admin/assets/uploads/' . $getData->image))) {

            \File::delete(public_path('admin/assets/uploads/' . $getData->image));
        }
        $getData->delete();
        return back()->with('success', 'Data Deleted Successfully !');
    }

    public function scholarship()
    {
        $scholarship=DB::table('scholarship')->where('user_id',Auth::user()->id)->get();
        return view("admin.scholarship",compact('scholarship'));
    }

    public function viewscholarship()
    {
        $scholarship=DB::table('users')
        ->join('scholarship', 'users.id', '=', 'scholarship.user_id')
        ->get();
        return view("admin.viewscholarship",compact('scholarship'));
    }

    public function portal_users()
    {
        $users=DB::table('users')
        ->where('admin_type','!=','user')
        ->get();
        return view("admin.portal_users",compact('users'));
    }
    public function online_users()
    {
        $users=DB::table('users')
        ->where('admin_type','=','user')
        ->get();
        return view("admin.portal_users",compact('users'));
    }
    public function applicants()
    {
        $users=DB::table('users')
        ->where('admin_type','=','user')
        ->join('applied_scholarship', 'applied_scholarship.user_id', '=', 'users.id')
        ->join('scholarship', 'scholarship.id', '=', 'applied_scholarship.scholarship_id')
        ->get();

        return view("admin.applicants",compact('users'));
    }
    public function apply_scholarship($id,$id2)
    {

DB::table('applied_scholarship')->insert(
       array(
            'user_id'     =>   $id, 
            'scholarship_id'   =>   $id2,
     )
);

    return redirect()->route('admin.website')->with('success', 'Added successfully!');

    }

    public function website()
    {

        $ema=DB::table('notification')->take(10)->get();
        Session::put('noti', $ema);

        $scholarship=DB::table('scholarship')
        ->where('status',1)
        ->paginate(2);

        if(Auth::check()){
            $applied_scholarship=DB::table('applied_scholarship')->where('user_id',Auth::user()->id)->get();
        }else
            {
                $applied_scholarship=0;
            }

        return view("website.index",compact('scholarship','applied_scholarship'));
    }
    public function contactus()
    {
        $ema=DB::table('notification')->take(10)->get();
        Session::put('noti', $ema);
        return view("website.contactus");
    }


    public function aboutus()
    {
        $ema=DB::table('notification')->take(10)->get();
        Session::put('noti', $ema);
        return view("website.aboutus");
    }

    public function testimonial()
    {
        $ema=DB::table('notification')->take(10)->get();
        Session::put('noti', $ema);
        return view("website.testimonial");
    }
    public function change_status($id,$val)
    {
        DB::table('scholarship')->where('id',$id)->update(
       array(
            'status'     =>   $val,
     )
);
        return back()->with('success', 'Status updated Successfully !');
    }

    public function edit_scholarship($id)
    {
        $scholarship=DB::table('scholarship')->where('id',$id)->where('user_id',Auth::user()->id)->first();

        return view("admin.edit_scholarship",compact('scholarship'));
    }
    

    public function edit_scholarship_post(Request $request)
    {
        DB::table('scholarship')->where('id',$request->id)->update(
       array(
            'scholarship_name'     =>   $request->name, 
            'institute_name'   =>   $request->institute,
            'country'   =>   $request->country,
            's_type'   =>   $request->s_type,
            'amount'   =>   $request->amount,
            'cgpa'   =>   $request->cgpa,
            'description'   =>   $request->description,
            'start_date'   =>   $request->start_date,
            'end_date'   =>   $request->end_date,
            'updated_at'   =>   date('y-m-d'),
     )
);

    return redirect()->route('admin.scholarship')->with('success', 'Updated successfully!');
    }

    public function delete_scholarship($id)
    {
        $scholarship=DB::table('scholarship')->where('id',$id)->where('user_id',Auth::user()->id)->delete();
        return back()->with('success', 'Data Deleted Successfully !');
    }

    public function add_scholarship()
    {
        return view("admin.add_scholarship");
    }

    public function add_scholarship_post(Request $request)
    {
        $s_id=DB::table('scholarship')->insertGetId(
       array(
            'scholarship_name'     =>   $request->name, 
            'institute_name'   =>   $request->institute,
            'country'   =>   $request->country,
            's_type'   =>   $request->s_type,
            'amount'   =>   $request->amount,
            'cgpa'   =>   $request->cgpa,
            'description'   =>   $request->description,
            'start_date'   =>   $request->start_date,
            'end_date'   =>   $request->end_date,
            'user_id'   =>   Auth::user()->id,
            'created_at'   =>   date('y-m-d'),
     )
);

        DB::table('notification')->insert(
       array(
            'name'     =>   $request->name, 
            'scholarship_id'   =>   $s_id,
     )
);

    return redirect()->route('admin.scholarship')->with('success', 'Added successfully!');
    }

    public function products()
    {
        $products = Products::orderBy('id', 'desc')->get();
        return view("admin.products", compact('products'));
    }

    public function add_products()
    {
        $categories = Categories::orderBy('id', 'desc')->get();
        return view("admin.add_products", compact('categories'));
    }

    public function save_products(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'name' => 'required',
            'price' => 'required',
            'categoryid' => 'required',
            'stock' => 'required',
            'tags' => 'required',
            'description' => 'required'
        ]);

        if ($validator->fails()) {
            return back()->with('error', 'All Fields Required.');
        }
        $data['name'] = $request->name;
        $data['price'] = $request->price;
        if (isset($request->cut_price) && !empty($request->cut_price)) {
            $data['cut_price'] = $request->cut_price;
        }
        $data['categoryid'] = $request->categoryid;
        $data['stock'] = $request->stock;
        $data['tags'] = $request->tags;
        $data['description'] = $request->description;
        $data['slug'] = Str::slug($request->name);
        if ($request->hasFile('image')) {
            $image = $request->file('image');
            $image_new = time() . $image->getClientOriginalName();
            $image->move('admin/assets/uploads/', $image_new);
            $data['image'] = $image_new;
        }
        $CheckSlug = Products::where('slug', Str::slug($request->name))->count();
        if ($CheckSlug > 0) {
            return back()->with('error', 'This Name is already exist .');
        }
        $productdetail = Products::create($data);

        if ($request->hasFile('MoreImages')) {
            $imagessize = sizeof($request->MoreImages);
            for ($i = 0; $i < $imagessize; $i++) {
                $image = $request->file('MoreImages')[$i];
                $image_new = time() . $image->getClientOriginalName();
                $image->move('admin/assets/uploads/', $image_new);
                $ProductData['image'] = $image_new;
                $ProductData['productid'] = $productdetail->id;;
                ProductImages::create($ProductData);
            }

        }
        return redirect()->route('admin.products')->with('success', 'Product Added Successfully');
    }

    public function delete_product($id)
    {
        $getData = Products::findOrFail(decrypt($id));
        if (\File::exists(public_path('admin/assets/uploads/' . $getData->image))) {
            \File::delete(public_path('admin/assets/uploads/' . $getData->image));
        }

        if (!empty($getData->images)) {
            foreach ($getData->images as $images_image) {
                if (\File::exists(public_path('admin/assets/uploads/' . $images_image->image))) {
                    \File::delete(public_path('admin/assets/uploads/' . $images_image->image));
                }
            }
        }
        $getData->delete();
        return back()->with('success', 'Data Deleted Successfully !');
    }

    public function edit_product($id)
    {
        $product = Products::findOrFail(decrypt($id));
        $categories = Categories::orderBy('id', 'desc')->get();
        return view('admin.edit_product', compact('product', 'categories'));
    }

    public function update_products(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'id' => 'required',
            'name' => 'required',
            'price' => 'required',
            'categoryid' => 'required',
            'stock' => 'required',
            'tags' => 'required',
            'description' => 'required'
        ]);

        if ($validator->fails()) {
            return back()->with('error', 'All Fields Required.');
        }
        $getData = Products::findOrFail($request->id);
        $getData->name = $request->name;
        $getData->price = $request->price;
        $getData->categoryid = $request->categoryid;
        $getData->stock = $request->stock;
        $getData->tags = $request->tags;
        if (isset($request->cut_price) && !empty($request->cut_price)) {
            $getData->cut_price = $request->cut_price;
        }
        if ($request->hasFile('image')) {
            $validator = Validator::make($request->all(), [
                'image' => 'required|image|mimes:jpg,png,jpeg,gif,svg'
            ]);

            if ($validator->fails()) {
                return back()->withInput()->with('error', 'Invalid Property image');
            }
            if (\File::exists(public_path('admin/assets/uploads/' . $getData->image))) {
                \File::delete(public_path('admin/assets/uploads/' . $getData->image));
            }
            $image = $request->file('image');
            $image_new = time() . $image->getClientOriginalName();
            $image->move('admin/assets/uploads/', $image_new);
            $getData->image = $image_new;
        }
        $getData->update();
        return redirect()->route('admin.products')->with('success', 'Product Successfully Updated');
    }

    public function edit_product_images($id)
    {
        $product = Products::findOrFail(decrypt($id));
        return view('admin.edit_product_images', compact('product'));
    }

   

    public function save_product_image(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'productid' => 'required',
            'image' => 'required'
        ]);

        if ($validator->fails()) {
            return back()->with('error', 'All Fields Required.');
        }
        if ($request->hasFile('image')) {
            $image = $request->file('image');
            $image_new = time() . $image->getClientOriginalName();
            $image->move('admin/assets/uploads/', $image_new);
            $data['image'] = $image_new;
            $data['productid'] = $request->productid;
            ProductImages::create($data);
        }
        return redirect()->back()->with('success', 'Successfully Added.');
    }

    public function delete_product_image($id)
    {
        $getData = ProductImages::findOrFail(decrypt($id));
        if (\File::exists(public_path('admin/assets/uploads/' . $getData->image))) {
            \File::delete(public_path('admin/assets/uploads/' . $getData->image));
        }
        $getData->delete();
        return back()->with('success', 'Data Deleted Successfully !');
    }

    public function orders()
    {
        $active_orders = Orders::where('status', 'active')->get();
        $completed_orders = Orders::where('status', 'completed')->get();
        return view("admin.orders", compact('active_orders', 'completed_orders'));
    }

    public function mark_as_complete($id)
    {
        $order = Orders::findOrFail($id);
        $order->update(['status' => 'completed']);
        return back()->with('success', 'Successfully Updated !');
    }

    public function order_detail($id)
    {
        $order = Orders::findOrFail(decrypt($id));
        return view("admin.order_detail", compact('order'));
    }
    public function submit_query(Request $request)
    {
        DB::table('contactus')->insert(
       array(
            'name'     =>   $request->name, 
            'email'   =>   $request->email,
            'subject'   =>   $request->subject,
            'message'   =>   $request->message,
     )
);

     return back()->with('success', 'Query Submit to admin Successfully !');


    }

    public function contact_messages()
    {
        $contact_messages = ContactMessage::all();
        return view("admin.contact_messages", compact('contact_messages'));
    }

    public function delete_contact_message($id)
    {
        $getData = ContactMessage::findOrFail(decrypt($id));
        $getData->delete();
        return back()->with('success', 'Data Deleted Successfully !');
    }

    public function food()
    {
     $products = Products::orderBy('id', 'desc')->get();
        return view("admin.products", compact('products'));
    }

}
